@@ -11,6 +11,7 @@ import types
 
 from django.db import models
 from django.db.models import ManyToOneRel
+from django.core.exceptions import FieldDoesNotExist
 
 NEVER = 0
 ALWAYS = 1
@@ -80,7 +81,7 @@ def _get_filtered_field_value(
     else:
         try:
             val = getattr(inst, field_name)
-        except (AttributeError, models.fields.FieldDoesNotExist) as e:  # noqa
+        except (AttributeError, FieldDoesNotExist) as e:  # noqa
             return None
 
     if isinstance(val, models.Manager):
@@ -106,7 +107,10 @@ def _get_filtered_field_value(
         return None
 
 
-def _apply_filters_to_object(inst, filter_def, expand_children=None, klass=None):
+# TODO: make this method less complex and remove the `noqa`
+def _apply_filters_to_object(  # noqa: C901
+    inst, filter_def, expand_children=None, klass=None
+):
     if isinstance(inst, (list, tuple, models.query.QuerySet)):
         # if it's a tuple or list, iterate over the collection and call _apply_filters_to_object on each item
         return [
